import { r as registerInstance, h, g as getElement } from './p-597600b0.js';

const adsVideoCss = ":root{font-family:Roboto}.d-none{display:none}.v-hidden{visibility:hidden}.c-pointer{cursor:pointer}.disabled{cursor:not-allowed;opacity:0.6}.fw-bold{font-weight:bold}::-webkit-scrollbar-track{background-color:var(--color-ti-bg-grey);border-radius:5px}::-webkit-scrollbar{background-color:var(--color-ti-bg-grey);height:5px;width:5px}::-webkit-scrollbar-thumb{background-color:var(--color-ti-text-grey);border-radius:5px}:host{display:flex;height:100%;width:100%}:host .main-video{cursor:pointer;height:100%;outline:none;position:relative;width:100%}:host .paused{opacity:0.5}:host .play-icon{cursor:pointer;left:50%;opacity:0.6;position:absolute;top:50%;transform:translate(-50%, -50%)}.thumbnail{background-color:var(--color-ti-primary-black);cursor:pointer;height:100%;position:relative;width:100%}.thumbnail gc-widget-icon{--gc-color:var(--color-ti-primary-white)}.thumbnail .overlay{align-items:center;color:var(--color-ti-white);display:flex;flex-direction:column;gap:1em;height:100%;justify-content:center;opacity:0.7;position:absolute;width:100%}.thumbnail video{height:100%;opacity:0.1;width:100%}";

const AdsVideo = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    // ---------- Internal variables ----------
    this.videoPosition = 0;
    // ---------- Event handlers ----------
    /**
     * To play/pause the video
     */
    this.toggleVideoPlay = () => {
      let mainVideo = this.host.shadowRoot.querySelector("#mainVideo");
      if (mainVideo) {
        mainVideo.dispatchEvent(new Event(mainVideo.paused ? "play" : "pause"));
      }
    };
    /**
     * To open the video popup
     */
    this.openVideoPopup = () => {
      this.isShowVideoPopup = true;
      setTimeout(() => {
        let mainVideo = this.host.shadowRoot.querySelector("#mainVideo");
        if (mainVideo) {
          mainVideo.currentTime = this.videoPosition;
          mainVideo.play();
        }
      }, 100);
    };
    /**
     * To close the video popup
     */
    this.onVideoPopupClosed = () => {
      let mainVideo = this.host.shadowRoot.querySelector("#mainVideo");
      this.isShowVideoPopup = false;
      if (mainVideo) {
        if (!mainVideo.paused) {
          mainVideo.pause();
        }
        if (mainVideo.duration === mainVideo.currentTime) {
          this.videoPosition = 0;
        }
        else {
          this.videoPosition = mainVideo.currentTime;
        }
      }
    };
    this.videoSrc = undefined;
    this.isShowVideoPopup = false;
    this.isMainVideoPaused = false;
  }
  // ---------- Watch handlers ----------
  _loadVideo() {
    let videoThumbnail = this.host.querySelector(".video-thumbnail");
    if (videoThumbnail) {
      videoThumbnail.load();
    }
  }
  // ---------- Life cycle methods ----------
  componentDidLoad() {
    let mainVideo = this.host.shadowRoot.querySelector("#mainVideo");
    if (mainVideo) {
      mainVideo.addEventListener("play", () => (this.isMainVideoPaused = false));
      mainVideo.addEventListener("pause", () => (this.isMainVideoPaused = true));
    }
  }
  render() {
    return [
      h("ads-popup", { isShowPopup: this.isShowVideoPopup, onPopupClosed: this.onVideoPopupClosed }, h("div", { slot: "content" }, h("video", { id: "mainVideo", class: "main-video " + (this.isMainVideoPaused ? "paused" : ""), controls: true, onClick: this.toggleVideoPlay }, h("source", { src: this.videoSrc, type: "video/ogg" })), this.isMainVideoPaused ? (h("gc-widget-icon", { class: "play-icon", appearance: "custom", icon: "filled:av:play_arrow", size: "xl", onClick: this.toggleVideoPlay })) : (""))),
      h("div", { class: "thumbnail", onClick: this.openVideoPopup }, h("div", { class: "overlay" }, h("div", null, h("gc-widget-icon", { appearance: "custom", icon: "filled:av:play_arrow" })), h("div", null, "Video Tutorial")), h("video", null, h("source", { src: this.videoSrc, type: "video/ogg" }))),
    ];
  }
  get host() { return getElement(this); }
  static get watchers() { return {
    "videoSrc": ["_loadVideo"]
  }; }
};
AdsVideo.style = adsVideoCss;

export { AdsVideo as ads_video };

//# sourceMappingURL=p-15b55100.entry.js.map